#
# spec file for package perl-Redis
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Redis
Name:           perl-Redis
Version:        2.000
Release:        1.3
License:        Artistic-2.0
Summary:        Perl binding for Redis database
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/D/DA/DAMS/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Digest::SHA)
BuildRequires:  perl(ExtUtils::MakeMaker) >= 6.63_03
BuildRequires:  perl(IO::Socket::Timeout) >= 0.29
BuildRequires:  perl(IO::String)
BuildRequires:  perl(IPC::Cmd)
BuildRequires:  perl(Module::Build::Tiny) >= 0.034
BuildRequires:  perl(Test::Deep)
BuildRequires:  perl(Test::Fatal)
BuildRequires:  perl(Test::More) >= 0.98
BuildRequires:  perl(Test::SharedFork)
BuildRequires:  perl(Test::TCP) >= 1.19
BuildRequires:  perl(Try::Tiny)
Requires:       perl(IO::Socket::Timeout) >= 0.29
Requires:       perl(Try::Tiny)
%{perl_requires}

%description
Pure perl bindings for https://redis.io/

This version supports protocol 2.x (multi-bulk) or later of Redis available
at https://github.com/antirez/redis/.

This documentation lists commands which are exercised in test suite, but
additional commands will work correctly since protocol specifies enough
information to support almost all commands with same piece of code with a
little help of 'AUTOLOAD'.

%prep
%autosetup  -n %{cpan_name}-%{version}
find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Build.PL --installdirs=vendor
./Build build --flags=%{?_smp_mflags}

%check
./Build test

%install
./Build install --destdir=%{buildroot} --create_packlist=0
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README
%license LICENSE

%changelog
* Sat Jan 14 2023 Tina Müller <timueller+perl@suse.de>
- updated to 2.000
  see /usr/share/doc/packages/perl-Redis/Changes
  2.000     2023-01-13 22:55:51+01:00 Europe/Paris
  * #166: add ssl, username and password args to redis sentinel (Merwan Ouddane)
  * #163: Add support for username/password AUTH (Joel Chornik)
  * #162: Retry socket connect if errno is EINTR (Michael Schout)
  * #158: Better fix of redis version in test (Michal Josef Špaček)
  * #156: Fix of test for multiple arguments in info command (Michal Josef Špaček)
* Sat Jan 15 2022 Tina Müller <timueller+perl@suse.de>
- updated to 1.999
  see /usr/share/doc/packages/perl-Redis/Changes
* Wed Aug 19 2020 Tina Müller <timueller+perl@suse.de>
- updated to 1.998
  see /usr/share/doc/packages/perl-Redis/Changes
  1.998     2020-08-18 11:04:12+02:00 Europe/Paris
  * remove test expression that is problematic on OpenBSD and NetBSD
  1.997     2020-80-17 10:03:00+01:00 Europe/Paris
  * various travis fixes
  * #112 applied
  * enable unix socket tests by enabling them in the local test server
  * #144: change exists into defined
  * #146: Fix sentinel option typo
* Fri Mar  6 2020 <timueller+perl@suse.de>
- updated to 1.996
  see /usr/share/doc/packages/perl-Redis/Changes
  1.996     2020-03-05 16:17:21+01:00 Europe/Paris
  1.996     2020-03-05 11:56:11+01:00 Europe/Paris
  * #139: Fix for "Unexpected error condition 104/linux"
* Tue Jul 23 2019 Stephan Kulow <coolo@suse.com>
- updated to 1.995
  see /usr/share/doc/packages/perl-Redis/Changes
  1.995     2019-07-22 11:20:07+02:00 Europe/Paris
  * revert #136, remove deps that are in core, as it breaks builds in some setup
  1.994     2019-07-22 07:51:57+02:00 Europe/Paris
  * Don't send SELECT if current database equals the one being selected (@dallaylaen, #132)
  1.993     2019-07-22 07:01:30+02:00 Europe/Paris
  * fix missing deps (@manwar, #136 )
* Mon Jul 22 2019 Stephan Kulow <coolo@suse.com>
- updated to 1.992
  see /usr/share/doc/packages/perl-Redis/Changes
  1.992     2019-07-21 18:27:23+02:00 Europe/Paris
  * relax the check in 04-pipeline.t about unknown command output (#130)
* Wed Aug 24 2016 coolo@suse.com
- updated to 1.991
  see /usr/share/doc/packages/perl-Redis/Changes
  1.991     2016-08-23 16:04:29CEST+0200 Europe/Paris
  * release as a normal release after successful testing of the dev releases
  1.990_02  2016-08-06 20:30:30CEST+0200 Europe/Paris
  * move reconnection test in reconnect test file to avoid test issues
    (skip_all but still run some tests)
  1.990_01  2016-08-05 17:17:28CEST+0200 Europe/Paris
  * fix issue #122: don't attempt to close an already closed or undefined socket
  * fix issue #120 and #111: don't depend on locales for matching error messages
  * fix issue #118: spelling mistake
  * fix issue #116: forbid continuing using socket after a read timeout
  * fix issue #115: Unexpected error condition 54/freebsd
* Sat Feb 13 2016 coolo@suse.com
- updated to 1.982
  see /usr/share/doc/packages/perl-Redis/Changes
  1.982     2016-02-11 09:02:40CET+0100 Europe/Paris
  * fix issue #117: fix backward compatibility with 5.8
* Sun Oct  4 2015 coolo@suse.com
- updated to 1.981
  see /usr/share/doc/packages/perl-Redis/Changes
  1.981     2015-09-29 12:31:57CEST+0200 Europe/Paris
  * fix a bug where when not yet connected, pid is undef, leading to warnings
* Mon Aug 24 2015 coolo@suse.com
- updated to 1.980
  see /usr/share/doc/packages/perl-Redis/Changes
  1.980     2015-08-24 09:48:08CEST+0200 Europe/Paris
  * fix "set" documentation as per Emanuele Tomasi <et@libersoft.it> suggestion
* Mon Jun 15 2015 coolo@suse.com
- updated to 1.979
  see /usr/share/doc/packages/perl-Redis/Changes
  1.979     2015-05-14 14:28:35CEST+0200 Europe/Amsterdam
  * depends on IO::Socket::Timeout 0.29 that fixes an important bug on
    Windows, Solaris, when mixing sockets with and without timeouts.
* Mon Apr 13 2015 coolo@suse.com
- updated to 1.978
  see /usr/share/doc/packages/perl-Redis/Changes
  1.978     2015-01-28 09:52:27 Europe/Amsterdam
  * reshape the documentation
  * croak when reconnecting while responses are pending (#101)
  * merge PR#106 ( support "0" in topic )
  1.977     2015-01-28 01:10:31 Europe/Amsterdam
  1.976     2014-10-03 15:05:58 Europe/Amsterdam
  1.975     2014-08-03 20:50:25 Europe/Amsterdam
  * Clarification about reconnect and read_timeout (#89)
  * Test::CPAN::Meta (et al.) are required even if unused (#92)
* Fri Jul 25 2014 coolo@suse.com
- updated to 1.974
  * release again, last one was screwed up.
  * fix #85 (PR #86) reconnect during transaction
  1.973_03  2014-05-12 22:49:07 Europe/Amsterdam
  * fix #85 (PR #86) reconnect during transaction
  1.973_02  2014-04-30 12:04:29 Europe/Amsterdam
  * merge PR #84 optimize try read sock
  1.973_01  2014-04-26 18:00:31 Europe/Amsterdam
  * use new network code from Ivan Kruglov
  * fix sentinel tests
  * fix #81: doc for 'every' option
* Tue Mar 18 2014 coolo@suse.com
- updated to 1.972
  * Sentinel features (connections, timeouts, etc) support
  * various bugfixes and testfixes
  * fix network code for BSDs
  * no_auto_connect_on_new
  1.971     2014-02-01 09:55:11 Europe/Paris
  * skip some tests that fail on some platforms for now
  1.970     2014-01-30 15:07:42 Europe/Amsterdam
  * fix tests breaking in some case
  1.969     2014-01-30 13:19:28 Europe/Amsterdam
  * Clarification for (p)unsubscribe commands.
  * use Test::TCP for testing
  1.968     2014-01-30 12:19:11 Europe/Amsterdam
  * Add a no_auto_connect_on_new parameter to new() to allow users
    to call $x = Redis->new and then $x->connect, instead of Redis
    auto-connecting. Useful for tuning the cnx_timeout parameter.
  1.967     2013-12-28 22:58:55 Europe/Paris
  * use new IO::Socket::Timeout with different API
  1.966     2013-12-17 13:58:33 Europe/Amsterdam
  * fix tests for Redis 2.8
* Sun May  1 2011 coolo@opensuse.org
- initial package 1.904
  * created by cpanspec 1.78.04
